==> zio-aws-lexruntimev2_3-5.17.127.2-sources.jar: zio/aws/lexruntimev2/model/DisconnectionEvent.scala <==
package zio.aws.lexruntimev2.model
import zio.aws.lexruntimev2.model.primitives.{EpochMillis, EventId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DisconnectionEvent(
    eventId: Option[EventId] = None,
    clientTimestampMillis: Option[EpochMillis] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent = {
    import DisconnectionEvent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
      .builder()
      .optionallyWith(
        eventId.map(value => EventId.unwrap(value): java.lang.String)
      )(_.eventId)
      .optionallyWith(
        clientTimestampMillis.map(value =>
          EpochMillis.unwrap(value): java.lang.Long
        )
      )(_.clientTimestampMillis)
      .build()
  }
  def asReadOnly: zio.aws.lexruntimev2.model.DisconnectionEvent.ReadOnly =
    zio.aws.lexruntimev2.model.DisconnectionEvent.wrap(buildAwsValue())
}
object DisconnectionEvent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexruntimev2.model.DisconnectionEvent =
      zio.aws.lexruntimev2.model.DisconnectionEvent(
        eventId.map(value => value),
        clientTimestampMillis.map(value => value)
      )
    def eventId: Option[EventId]
    def clientTimestampMillis: Option[EpochMillis]
    def getEventId: ZIO[Any, AwsError, EventId] =
      AwsError.unwrapOptionField("eventId", eventId)
    def getClientTimestampMillis: ZIO[Any, AwsError, EpochMillis] =
      AwsError.unwrapOptionField("clientTimestampMillis", clientTimestampMillis)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
  ) extends zio.aws.lexruntimev2.model.DisconnectionEvent.ReadOnly {
    override val eventId: Option[EventId] = scala
      .Option(impl.eventId())
      .map(value => zio.aws.lexruntimev2.model.primitives.EventId(value))
    override val clientTimestampMillis: Option[EpochMillis] = scala
      .Option(impl.clientTimestampMillis())
      .map(value => zio.aws.lexruntimev2.model.primitives.EpochMillis(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
  ): zio.aws.lexruntimev2.model.DisconnectionEvent.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lexruntimev2_3-6.20.42.1-sources.jar: zio/aws/lexruntimev2/model/DisconnectionEvent.scala <==
package zio.aws.lexruntimev2.model
import zio.aws.lexruntimev2.model.primitives.{EpochMillis, EventId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DisconnectionEvent(
    eventId: Optional[EventId] = Optional.Absent,
    clientTimestampMillis: Optional[EpochMillis] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent = {
    import DisconnectionEvent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
      .builder()
      .optionallyWith(
        eventId.map(value => EventId.unwrap(value): java.lang.String)
      )(_.eventId)
      .optionallyWith(
        clientTimestampMillis.map(value =>
          EpochMillis.unwrap(value): java.lang.Long
        )
      )(_.clientTimestampMillis)
      .build()
  }
  def asReadOnly: zio.aws.lexruntimev2.model.DisconnectionEvent.ReadOnly =
    zio.aws.lexruntimev2.model.DisconnectionEvent.wrap(buildAwsValue())
}
object DisconnectionEvent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexruntimev2.model.DisconnectionEvent =
      zio.aws.lexruntimev2.model.DisconnectionEvent(
        eventId.map(value => value),
        clientTimestampMillis.map(value => value)
      )
    def eventId: Optional[EventId]
    def clientTimestampMillis: Optional[EpochMillis]
    def getEventId: ZIO[Any, AwsError, EventId] =
      AwsError.unwrapOptionField("eventId", eventId)
    def getClientTimestampMillis: ZIO[Any, AwsError, EpochMillis] =
      AwsError.unwrapOptionField("clientTimestampMillis", clientTimestampMillis)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
  ) extends zio.aws.lexruntimev2.model.DisconnectionEvent.ReadOnly {
    override val eventId: Optional[EventId] = zio.aws.core.internal
      .optionalFromNullable(impl.eventId())
      .map(value => zio.aws.lexruntimev2.model.primitives.EventId(value))
    override val clientTimestampMillis: Optional[EpochMillis] =
      zio.aws.core.internal
        .optionalFromNullable(impl.clientTimestampMillis())
        .map(value => zio.aws.lexruntimev2.model.primitives.EpochMillis(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DisconnectionEvent
  ): zio.aws.lexruntimev2.model.DisconnectionEvent.ReadOnly = new Wrapper(impl)
}
